@@ -18,13 +18,16 @@ con.setLevel(logging.INFO)
 formatter = logging.Formatter('%(message)s')
 con.setFormatter(formatter)
 logger.addHandler(con)
+tags={}
+def set_tags(key,value):
+        tags[key]=value
 
 def _log(msg, application, level,execution_time, user_id, extra_data):
         now =str( int(datetime.now().timestamp()))    
         environment = 'development' if config("ENVIRONMENT") == None or config("ENVIRONMENT")=="" else config("ENVIRONMENT")
         application = 'unknown' if config("APPLICATION") == None or config("APPLICATION")=="" else config("APPLICATION")
 
-        data={
+        original_data={
             "message": msg,
             "level": level,
             "application": application,
@@ -34,6 +37,7 @@ def _log(msg, application, level,execution_time, user_id, extra_data):
             "extra_data": extra_data,
             "timestamp": now
         }
+        data={**original_data, **tags}
 
         handler = logging.FileHandler(config('DIR')+now+'.log')
         handler.setLevel(logging.INFO)
